@@ -1,4 +1,4 @@
-# $Id: Manifest.pm 2506 2008-01-24 12:10:54Z comdog $
+# $Id: Manifest.pm 2599 2008-07-30 01:15:51Z comdog $
 package Test::Manifest;
 use strict;
 
@@ -14,7 +14,7 @@ use File::Spec::Functions qw(catfile);
 @EXPORT    = qw(run_t_manifest);
 @EXPORT_OK = qw(get_t_files make_test_manifest manifest_name);
 
-$VERSION = '1.22_02';
+$VERSION = '1.22_03';
 
 my $Manifest = catfile( "t", "test_manifest" );
 my %SeenInclude = ();
@@ -45,29 +45,30 @@ Test::Manifest - interact with a t/test_manifest file
 	
 =head1 DESCRIPTION
 
-Test::Harness assumes that you want to run all of the .t files in the
-t/ directory in ascii-betical order during C<make test> unless you say
+C<Test::Harness> assumes that you want to run all of the F<.t> files in the
+F<t/> directory in ascii-betical order during C<make test> unless you say
 otherwise.  This leads to some interesting naming schemes for test
 files to get them in the desired order. This interesting names ossify
 when they get into source control, and get even more interesting as
 more tests show up.
 
-Test::Manifest overrides the default behaviour by replacing the
+C<Test::Manifest> overrides the default behaviour by replacing the
 test_via_harness target in the Makefile.  Instead of running at the
-t/*.t files in ascii-betical order, it looks in the t/test_manifest
+F<t/*.t> files in ascii-betical order, it looks in the F<t/test_manifest>
 file to find out which tests you want to run and the order in which
 you want to run them.  It constructs the right value for MakeMaker to
 do the right thing.
 
-In t/test_manifest, simply list the tests that you want to run.  Their
+In F<t/test_manifest>, simply list the tests that you want to run.  Their
 order in the file is the order in which they run.  You can comment
-lines with a #, just like in Perl, and Test::Manifest will strip
+lines with a C<#>, just like in Perl, and C<Test::Manifest> will strip
 leading and trailing whitespace from each line.  It also checks that
-the specified file is actually in the t/ directory.  If the file does
-not exist, it does not put its name in the list of test files to run.
+the specified file is actually in the F<t/> directory.  If the file does
+not exist, it does not put its name in the list of test files to run and 
+it will issue a warning.
 
 Optionally, you can add a number after the test name in test_manifest
-to define sets of tests. See get_t_files() for more information.
+to define sets of tests. See C<get_t_files> for more information.
 
 =head2 Functions
 
@@ -219,6 +220,13 @@ sub _load_test_manifest
 		carp( "test file begins with t/ [$test]" ) if m|^t/|;
 		
 		$test = catfile( "t", $test ) if -e catfile( "t", $test );
+		
+		unless( -e $test )
+			{
+			carp( "test file [$test] does not exist! Skipping!" );
+			next;
+			}
+			
 		# Make sure we don't include a test we've already seen
 		next if exists $SeenTest{$test};
 
